@@ -15,5 +15,10 @@ class GenerateCalibratedData(ScienceTaskL0ToL1Base):
             output_hdul = fits.HDUList([output_hdu])
             self.fits_data_write(
                 hdu_list=output_hdul,
-                tags=[Tag.calibrated(), Tag.frame(), Tag.stokes("I")],
+                tags=[
+                    Tag.calibrated(),
+                    Tag.frame(),
+                    Tag.stokes("I"),
+                    Tag.dsps_repeat(header["DSPSNUM"]),
+                ],
             )
