@@ -10,6 +10,7 @@ from dkist_processing_core import Workflow
 
 from dkist_processing_test.tasks.fake_science import GenerateCalibratedData
 from dkist_processing_test.tasks.movie import AssembleTestMovie
+from dkist_processing_test.tasks.movie import MakeTestMovieFrames
 from dkist_processing_test.tasks.parse import ParseL0TestInputData
 from dkist_processing_test.tasks.write_l1 import WriteL1Data
 
@@ -31,11 +32,11 @@ generate_calibrated_data = Workflow(
 )
 generate_calibrated_data.add_node(task=GenerateCalibratedData, upstreams=None)
 
-# # GenerateL1OutputData Task
-# generate_l1_output_data = Workflow(
-#     process_category="test", process_name="generate_l1_output_data", workflow_package=__package__
-# )
-# generate_l1_output_data.add_node(task=GenerateL1OutputData, upstreams=None)
+# MakeTestMovieFrames task
+make_test_movie_frames = Workflow(
+    process_category="test", process_name="make_test_movie_frames", workflow_package=__package__
+)
+make_test_movie_frames.add_node(task=MakeTestMovieFrames, upstreams=None)
 
 # AssembleTestMovie Task
 assemble_test_movie = Workflow(
