@@ -10,7 +10,7 @@ from dkist_processing_core import Workflow
 
 from dkist_processing_test.tasks.fake_science import GenerateCalibratedData
 from dkist_processing_test.tasks.movie import AssembleTestMovie
-from dkist_processing_test.tasks.movie import MakeMovieFrames
+from dkist_processing_test.tasks.movie import MakeTestMovieFrames
 from dkist_processing_test.tasks.parse import ParseL0TestInputData
 from dkist_processing_test.tasks.write_l1 import WriteL1Data
 
@@ -41,10 +41,10 @@ end_to_end.add_node(task=TransferL0Data, upstreams=None)
 end_to_end.add_node(task=ParseL0TestInputData, upstreams=TransferL0Data)
 end_to_end.add_node(task=GenerateCalibratedData, upstreams=ParseL0TestInputData)
 end_to_end.add_node(task=WriteL1Data, upstreams=GenerateCalibratedData)
-# end_to_end.add_node(task=MakeMovieFrames, upstreams=WriteL1Data)
-# end_to_end.add_node(task=AssembleTestMovie, upstreams=MakeMovieFrames)
-end_to_end.add_node(task=TransferL1Data, upstreams=WriteL1Data)
-end_to_end.add_node(task=AddDatasetReceiptAccount, upstreams=WriteL1Data)
+end_to_end.add_node(task=MakeTestMovieFrames, upstreams=WriteL1Data)
+end_to_end.add_node(task=AssembleTestMovie, upstreams=MakeTestMovieFrames)
+end_to_end.add_node(task=TransferL1Data, upstreams=AssembleTestMovie)
+end_to_end.add_node(task=AddDatasetReceiptAccount, upstreams=AssembleTestMovie)
 end_to_end.add_node(
     task=PublishCatalogAndQualityMessages, upstreams=[TransferL1Data, AddDatasetReceiptAccount]
 )
